# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

- **Added** for new features.
- **Changed** for changes in existing functionality.
- **Deprecated** for soon-to-be removed features.
- **Removed** for now removed features.
- **Fixed** for any bug fixes.
- **Security** in case of vulnerabilities.

## [Unreleased]

## [3.0.0] - 2023-10-14

### Added

- [Python executables must be determined at run-time.](https://github.com/paulissoft/pato-gui/issues/11)

### Fixed

- [Pato gui script does not run due to missing pythonw executable.](https://github.com/paulissoft/pato-gui/issues/10)

## [2.1.0] - 2023-09-06

### Added

- [APEX seed and publish.](https://github.com/paulissoft/oracle-tools/issues/107)

### Fixed

- [The GUI does not start with a message that the property db.config.dir must have been set.](https://github.com/paulissoft/pato-gui/issues/8)

## [2.0.0] - 2022-11-23

### Added

- [Remove all references to Oracle Tools in documentation.](https://github.com/paulissoft/pato-gui/issues/7)

## [1.2.0] - 2022-10-13

### Added

- [It must be possible to use the Maven daemon.](https://github.com/paulissoft/pato-gui/issues/6)

## [1.1.1] - 2022-07-22

### Fixed

- [When you supply the database configuration directory as a relative path, the execution fails.](https://github.com/paulissoft/pato-gui/issues/5)

## [1.1.0] - 2021-09-10

### Added

- Added actions db-info and db-code (added in oracle-tools 1.2.0).

## [1.0.0] - 2021-06-04

### Added

- [Display information about the Java run-time and compiler.](https://github.com/paulissoft/pato-gui/issues/3)
- Applied Python best practices.
